Changlog
========

0.2.1
-----

* Fixing packaging issue - sdist package didn't include the templates off the app.

0.2.0
-----

* Adding link to change list linking to csv export.

0.1.0
-----

* Initial release
